-- Creating staging table
DROP TABLE IF EXISTS temp_app_rules;
CREATE TABLE temp_app_rules (
  package_name VARCHAR(100) PRIMARY KEY,
  traffic_filtering INTEGER DEFAULT 1,
  ad_blocking INTEGER DEFAULT 1,
  https_filtering INTEGER DEFAULT 1,
  firewall_notifications INTEGER DEFAULT 1,
  mobile_data INTEGER DEFAULT 1,
  wifi INTEGER DEFAULT 1,
  mobile_data_screen_off INTEGER DEFAULT 1,
  wifi_screen_off INTEGER DEFAULT 1
);

-- Default app rules
INSERT INTO temp_app_rules (package_name, traffic_filtering, ad_blocking, https_filtering,
    firewall_notifications, mobile_data, wifi, mobile_data_screen_off, wifi_screen_off)
    VALUES ('com.adguard.default.rules', 1, 1, 1, 1, 1, 1, 1, 1);
    -- https://github.com/AdguardTeam/AdguardForAndroid/issues/3025
INSERT INTO temp_app_rules (package_name, traffic_filtering, ad_blocking, https_filtering,
    firewall_notifications, mobile_data, wifi, mobile_data_screen_off, wifi_screen_off)
    VALUES ('com.adguard.dns', 1, 1, 1, 1, 1, 1, 1, 1);

--
-- Network exclusions list
--

INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.adguard.android', 0);

--/ ----- VPN and filtering apps start ----- ///

INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.drweb', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.drweb.pro', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.drweb.pro.market', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.opera.max', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.opera.max.global', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('me.disconnect.mobile2', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.mobisoft.webguard', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('app.greyshirts.firewall', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('hotspotshield.android.vpn', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('org.hola', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.tunnelbear.android', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.avast.android.vpn', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.spotflux.android', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('net.hideman', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.aed.droidvpn', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.zenmate.android', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.exalinks.neopard', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.simplexsolutionsinc.vpn_unlimited', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.googlecode.droidwall.free', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('org.torproject.android', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.onavo.android.onavoics', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/740
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.pandasecurity.pandaav', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/993
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.globus.vpn', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/995
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('net.probki.geonet', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/962
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('cityguide.probki.net', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/1068
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('ru.cardsmobile.mw3', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.cardsmobile.walletagent.common.hce', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1088
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.pcloud.pcloud', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1353
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.nextbit.constellation', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1183
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('de.blinkt.openvpn', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1687
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.zte.android.ztelink', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2198
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.cisco.webex.meetings', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2399
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.apps.walletnfcrel', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2402
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('org.codeaurora.ims', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.service.ims', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.service.ims.presence', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.ims', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.carrier', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.carriersetup', 0);

--/ ----- VPN and filtering apps end ----- ///

--/ ----- SMS/MMS apps start ----- ///

-- Bug ID=AG-6501
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.thinkleft.eightyeightsms.mms', 0);
-- Some more mms apps
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.verizon.messaging.vzmsgs', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.mms', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.mms.service', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.motorola.messaging', 0);
-- Bug ID=AG-6596
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.textra', 0);
-- Bug ID=AG-6569
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('ru.mail.my', 0);
-- Blocking MMS, Bug ID=AG-6659
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.handcent.nextsms', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/75
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.handcent.app.nextsms', 0);
-- Bug ID=AG-6780
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.apps.messaging', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/49
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.p1.chompsms', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/302
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.project.materialmessaging', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/412
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.skt.prod.tmessage', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/499
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.disa', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2775
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.turkcell.bip', 0);

--/ ----- SMS/MMS apps end ----- ///

--/ ----- Apps accessing LAN start ----- ///

-- Roku - unable to find devices on network
-- Bug ID=AG-7965
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.roku.remote', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/237
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.samsung.android.app.FileShareClient', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.samsung.android.app.FileShareServer', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/245
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.lge.qremote', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3181
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.playstation.remoteplay', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/495
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.gopro.smarty', 0);

-- Bug ID=AG-6656
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.amazon.storm.lightning.client.aosp', 0);
-- Sonos controller
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.sonos.acr', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1670
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.verisign.mvip.main', 0);

--/ ----- Apps accessing LAN end ----- ///

--/ ----- Other issues start ----- ///

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1052
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.providers.media', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.mtp', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.providers.downloads', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.providers.downloads.ui', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.vending', 0);

-- PAC Console - ROM updater
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.pac.console', 0);
-- Bug ID=AG-6993
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.sec.spp.push', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/135
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('org.appwork.myjdandroid', 0);

-- Auto authorization in Mosmetro
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/246
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.slimd0g.automosmetrowifi', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('pw.thedrhax.mosmetro', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/422
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.zoiper.android.app', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.csipsimple', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/321
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.rcreations.WebCamViewerPaid', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/127
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.dnset', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/607
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.tmobile.pr.mytmobile', 0);

-- Bug ID=AG-6426
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.providers.drm', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/673
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.samsung.syncservice', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1505
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('epic.mychart.android', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1790
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.apps.nbu.paisa.user', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3185
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.apps.searchlite', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1868
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.stackpath.cloak', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1868
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.blizzard.bma', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1891
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.samsung.android.scloud', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1982
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('ua.privatbank.ap24', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('ua.privatbank.ap24.old', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2037
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('ca.tangerine.clients.phone', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2028
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.nest.android', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2180
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.samsung.android.samsungpay.gear', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2324
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.microsoft.appmanager', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2713
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.google.android.captiveportallogin', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.android.captiveportallogin', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2953
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.sipnetic.app', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3147
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('by.gis.gidrometweather', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3281
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.nttdocomo.keitai.payment', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('com.kddi.android.cmail', 0);
INSERT INTO temp_app_rules (package_name, traffic_filtering) VALUES ('jp.videomarket.mb', 0);

--/ ----- Other issues end ----- ///

--
-- Ad blocking exclusions list
--

-- http://jira.performix.ru/browse/AG-6266
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('maximsblog.blogspot.com.tv', 0);
-- http://jira.performix.ru/browse/AG-6748
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.livejournal.android', 0);
-- http://jira.performix.ru/browse/AG-6787
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.yandex.dictation', 0);
-- blocking ads breaks video player
-- Bug ID=AG-7983
INSERT INTO temp_app_rules (package_name, traffic_filtering, ad_blocking) VALUES ('tv.vintera.smarttv', 0, 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/195
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('tv.periscope.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/350
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.osp.app.signin', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/364
-- http://forum.adguard.com/showthread.php?9186
INSERT INTO temp_app_rules (package_name, traffic_filtering, ad_blocking) VALUES ('com.bvblogic.nimbusnote', 0, 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/374
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.nektome.talk', 0);

-- https://github.com/AdguardTeam/AdguardForAndroid/issues/45
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.zynga.FarmVille2CountryEscape', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/327
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.google.android.apps.adwords', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.google.android.apps.ads.express', 0);
-- Bug ID=AG-6744
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.gameville.volleyhangout', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/658
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.google.android.calendar', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/883
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.virginmedia.tvanywhere', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/781
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.melodis.midomiMusicIdentifier.freemium', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.melodis.midomiMusicIdentifier', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1236
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.netmarble.sknightsgb', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1330
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.ftt.lostkaos', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2038
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.scannerradio', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2186
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.zing.zalo', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2917
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.kms.free', 0);

--/ ----- Banking apps ----- ///
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/169
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.sberbankmobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.alfabank.mobile.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.alfabank.oavdo.amc', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.idamob.tinkoff.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.tcsbank.wallet', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3196
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.simpls.mbrd.ui.beta', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.simpls.mbrd.ui', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/414
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('se.nordea.mobilebank', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('se.bankgirot.swish', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.bankid.bus', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/414
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.htsu.hsbcpersonalbanking', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('au.com.ingdirect.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/397
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.bkm.mobil', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.pozitron.iscep', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.ykb.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.paypal.android.p2pmobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.ziraat.ziraatmobil', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('tr.com.sekerbilisim.mbank', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.openbank', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.konylabs.capitalone', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('subsembly.banking', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/702
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('de.dkb.portalapp', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.starfinanz.mobile.android.dkbpushtan', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.centralway.numbrs', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/637
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('kz.crystalspring.bankofastana', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/743
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.ally.MobileBanking', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/832
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.megafon.bank', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/848
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.axabanque.fr', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/851
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.raiffeisennews', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('eu.eleader.mobilebanking.raiffeisen', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.advantage.RaiffeisenBank', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ch.raiffeisen.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.isis_papyrus.raiffeisen_pay_eyewdg', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ch.raiffeisen.phototan', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.guidance.android.apps.raiffeisen.banklet', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.evolaris.rmclub', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.hal.mbank', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('hr.asseco.android.jimba.rmb', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.raiffeisen.online.mobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('rs.Raiffeisen.mobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('lu.raiffeisen.mobile.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.rb.app.smartphonebanking', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ua.pentegy.avalbank.production', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('at.racon.ebba', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.infinum.rba', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/852
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('uk.co.tsb.mobilebank', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/945
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.letobank.Prometheus', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1013
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.sc.danb.scbankapp', 0);
-- https://github.com/AdguardTeam/HttpsExclusions/issues/1
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.venmo', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1145
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.ing.mobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.ing.mobilepayments', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1287
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('de.number26.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.chase.sig.android', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.wf.wellsfargomobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.bnpp.easybanking', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.discoverfinancial.mobile', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('mobi.societegenerale.mobile.lappli', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('de.commerzbanking.mobil', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.db.mm.deutschebank', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.usbank.mobilebanking', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.infonow.bofa', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1361
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.banksimple', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1411
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.mobicon.mbank2.belarusbank', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1638
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.finansbank.mobile.cepsube', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.garanti.cepsubesi', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.freecharge.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1694
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.kbstar.kbbank', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1699
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.otsar.nativeapp', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1710
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('finansbank.enpara', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('finansbank.enpara.sirketim', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1777
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.no.entercard.coopmastercard', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('se.entercard.remember', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('be.bankvanbreda.mobile', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1981
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('wit.android.bcpBankingApp.millenniumPL', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2150
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.pnc.ecommerce.mobile', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2945
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.nordea.mobiletoken', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2957
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.fortuneo.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3082
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.citibank.mobile.ru', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3157
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.csas.georgego', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.csas.app.georgeklic', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.csas.app.friends24', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.csas.app.poketka', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.cleverlance.csas.servis24', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.csas.app.mujstav', 0);
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('cz.csas.business24', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3205
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('fr.banquepopulaire.cyberplus', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3222
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.finanteq.finance.bgz', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3262
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.fd.accessplusecs.aqua', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3263
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.alrayanbankuk.mobile', 0);
-- https://jira.adguard.com/browse/AG-1138
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('ru.mkb.mobile', 0);
-- https://jira.adguard.com/browse/AG-1431
INSERT INTO temp_app_rules (package_name, ad_blocking) VALUES ('com.alseda.bapb', 0);
--/ ----- Bank apps end ----- ///

--
-- HTTPS exclusions list
--

-- Facebook apps
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.facebook.katana', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.facebook.orca', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.instagram.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1135
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.microsoft.cortana', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/320
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.taxi', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/385
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.sec.android.app.samsungapps', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/438
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.facebook.lite', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/427
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.ubercab', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/466
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.americanexpress.android.acctsvcs.us', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/465
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.payoneer.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/469
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.snapchat.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/418
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.twitter.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/396
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('gbis.gbandroid', 0);
-- https://github.com/AdguardTeam/ExperimentalFilter/issues/2008
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.mShop.android.shopping', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/394
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('de.lotum.whatsinthefoto.us', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/395
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('air.com.freshplanet.games.SongPop2', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/492
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.tranzmate', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/531
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.smartthings.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/588
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.rambler.mail', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/559
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.mts.music.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/612
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.jet.jet.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/676
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.kindle', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.sellermobile.android', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.mShop.android', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('uk.amazon.mShop.android', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.windowshop', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.drive', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.clouddrive.photos', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.venezia', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/655
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('nl.sanomamedia.android.nu', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/686
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.planetromeo.android.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/659
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('by.euanpa.schedulegrodno', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/650
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('org.coursera.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/624
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.heetch', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/584
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.googlequicksearchbox', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/674
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.voiceserviceplatform', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/710
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.grindrapp.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/715
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.neuralprisma', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/447
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.yandexnavi', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/679
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.touchtype.swiftkey', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/680
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.lazada.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/733
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.waze', 0);
-- https://github.com/issues/assigned
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('de.idealo.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/679
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.touchtype.swiftkey.beta', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/388
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.mail', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1278
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.disk', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1296
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.market', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.weatherplugin', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/792
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.apple.android.music', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/753
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.apps.tachyon', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/789
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.siber.roboform', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/804
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.apps.fireball', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/826
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.skype.raider', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/831
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ua.com.rozetka.shop', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/845
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.sofascore.results', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/873
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.raumfeld.android.controller', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/890
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.dunkinbrands.otgo', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/895
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.beeline.services', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/900
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ua.novaposhtaa', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/898
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('rg.kman.AquaMail', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/915
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.cloudmosa.puffinFree', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.cloudmosa.puffin', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/916
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.themestore', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/920
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.citi.citimobile', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/942
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.microsoft.microsoftsolitairecollection', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/944
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.microsoft.office.lync15', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/991
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('org.cryptomator.beta app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/987
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.poloniumarts.svyaznoy', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1034
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('air.nn.mobile.app.main', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/965
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.youtube.tv', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1010
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.facebook.mlite', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1041
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.ecobee.athenamobile', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1040
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.nuance.swype.dtc', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.nuance.swype.trial', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/984
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.inputmethod.latin', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1093
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.korbit.trader', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1089
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.kaspersky.safekids', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/762
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yota.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1164
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.arvifox.hibiny', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1204
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.ivideon.client', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1273
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.nimses', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1347
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.mail.auth.totp', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.apps.authenticator2', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1347
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.authy.authy', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/1324
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.avito.android', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/1143
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ua.slando', 0);
--https://github.com/AdguardTeam/AdguardForAndroid/issues/1389
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samruston.twitter', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1400
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.bixby.wakeup', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.bixby.agent', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.bixby.es.globalaction', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.bixby.agent.dummy', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.bixby.voiceinput', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.samsung.android.bixby.plmsync', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1418
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('jp.naver.line.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1431
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.wealthfront', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1103
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.viber.voip', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1144
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.sports', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1515
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.apps.chromecast.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1518
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.bemyeyes.bemyeyes', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1531
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('mega.privacy.android.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1536
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.vkontakte.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1372
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.ok.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1591
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.fourpda.client', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1669
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.netgear.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1686
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.yandex.money', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1672
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.olacabs.customer', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1544
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.tellm.android.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1701
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('nl.rijksoverheid.digid.pub', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1718
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.droid4you.application.wallet', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1817
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.sonymobile.androidapp.audiorecorder', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1825
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.apps.maps', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1841
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.apps.tasks', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1860
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.mfoundry.mb.android.mb_031101321', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1866
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.lsdroid.cerberus', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1899
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('org.lumicall.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1940
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.bbm', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/1949
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.myyearbook.m', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2018
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.rostel', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2039
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.box.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2082
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.alseda.ideabank', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2103
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.gashpay.personal', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2106
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.sberbank.spasibo', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2246
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('in.amazon.mShop.android.shopping', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2283
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.olo.elpolloloco', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2385
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.google.android.wearable.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2551
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('widget.dd.com.overdrop.free', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2618
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ru.tinkoff.mvno', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2624
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.bskyb.skyq.it', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2920
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('gr.cosmote.whatsup', 0);
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('gr.cosmote.myaccount.widget', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2970
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ch.threema.app', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3121
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.automattic.simplenote', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3072
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.udemy.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/2824
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.vodafone.selfservis', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3277
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.amazon.avod.thirdpartyclient', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3306
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.scee.psxandroid', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3321
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('ch.protonvpn.android', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3322
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.readdle.spark', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3323
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.imdb.mobile', 0);
-- https://github.com/AdguardTeam/AdguardForAndroid/issues/3325
INSERT INTO temp_app_rules (package_name, https_filtering) VALUES ('com.vtosters.android', 0);

-- Insert new app rules
INSERT INTO app_rules (package_name, traffic_filtering, ad_blocking, https_filtering)
     SELECT package_name, traffic_filtering, ad_blocking, https_filtering
       FROM temp_app_rules t1
      WHERE NOT EXISTS (SELECT 1 FROM app_rules t2 WHERE t2.package_name = t1.package_name);

-- Drop staging table
DROP TABLE IF EXISTS temp_app_rules;